#
# spec file for package python3-pyzmq
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pyzmq
Version:        14.7.0
Release:        4.8
Summary:        Python bindings for 0MQ
License:        LGPL-3.0+
Group:          Development/Languages/Python
Url:            http://github.com/zeromq/pyzmq
Source:         http://pypi.python.org/packages/source/p/pyzmq/pyzmq-%{version}.tar.gz
Source1:        python3-pyzmq-rpmlintrc
BuildRequires:  python3
BuildRequires:  python3-Cython
BuildRequires:  python3-cffi
BuildRequires:  python3-devel
BuildRequires:  python3-numpy
BuildRequires:  python3-paramiko
BuildRequires:  python3-pexpect
BuildRequires:  python3-py
BuildRequires:  python3-setuptools
BuildRequires:  python3-simplejson
BuildRequires:  python3-tornado
BuildRequires:  zeromq-devel
# Not available yet in Python 3.x
# BuildRequires:  python3-gevent
# Test requirements
BuildRequires:  python3-nose
Requires:       python3
Recommends:     python3-cffi
Recommends:     python3-numpy
Recommends:     python3-pexpect
Recommends:     python3-py
Recommends:     python3-simplejson
Recommends:     python3-tornado
Recommends:     python3-paramiko
# Not available yet in Python 3.x
# Recommends:     python3-gevent
Recommends:     zeromq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PyZMQ is a lightweight and super-fast messaging library built on top of
the ZeroMQ library (http://www.zeromq.org).

%package devel
Summary:        Development files for %{name}
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python3-devel
Requires:       zeromq-devel

%description devel
Development libraries and headers needed to build software using %{name}.

%prep
%setup -q -n pyzmq-%{version}
# Fix non-executable script rpmlint warning:
find examples zmq -name "*.py" -exec sed -i "s|#\!\/usr\/bin\/env python||" {} \;

%build
CFLAGS="%{optflags}" python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
# Remove non-deterministic authentication test
# This fails to connect randomly
rm -rf zmq/tests/test_auth.py

python3 setup.py build_ext --inplace
python3 setup.py test

%files
%defattr(-,root,root,-)
%doc AUTHORS.md COPYING.BSD COPYING.LESSER README.md examples docs
%{python3_sitearch}/zmq/
%{python3_sitearch}/pyzmq-%{version}-py%{py3_ver}.egg-info
%exclude %{python3_sitearch}/zmq/utils/*.h
%exclude %{python3_sitearch}/zmq/backend/cffi/_verify.c
%exclude %{python3_sitearch}/zmq/backend/cffi/_cdefs.h

%files devel
%defattr(-,root,root,-)
%{python3_sitearch}/zmq/utils/*.h
%{python3_sitearch}/zmq/backend/cffi/_verify.c
%{python3_sitearch}/zmq/backend/cffi/_cdefs.h

%changelog
* Fri Sep 25 2015 stephan.barth@suse.com
- fixed build error by moving two files to the devel package:
  %%{python3_sitearch}/zmq/backend/cffi/_verify.c and _cdefs.h
* Thu Jul 30 2015 toddrme2178@gmail.com
- Disable non-deterministic authentication test.  It fails to
  connect randomly.
* Wed Jul 29 2015 toddrme2178@gmail.com
- Add additional optional dependencies that support additional
  features and/or additional backends.
* Mon Jun 29 2015 toddrme2178@gmail.com
- Use python3-Cython, not python-Cython
* Fri Jun 19 2015 arun@gmx.de
- update to version 14.7.0:
  * Changes:
    + Update bundled libzmq to 4.1.2.
    + Following the lead of Python 3.5, interrupted system calls will
    be retried.
  * Fixes:
    + Fixes for CFFI backend on Python 3 + support for PyPy 3.
    + Verify types of all frames in :meth:`~zmq.Socket.send_multipart`
    before sending, to avoid partial messages.
    + Fix build on Windows when both debug and release versions of
    libzmq are found.
    + Windows build fixes for Python 3.5.
* Fri Apr 24 2015 arun@gmx.de
- update to version 14.6.0:
  * Changes:
    + improvements in :meth:`zmq.Socket.bind_to_random_port`:
    o use system to allocate ports by default
    o catch EACCES on Windows
    + include libsodium when building bundled libzmq on Windows (includes wheels on PyPI)
    + pyzmq no longer bundles external libzmq when making a bdist. You can use delocate to do this.
  * Bugfixes:
    + add missing :attr:`ndim` on memoryviews of Frames
    + allow :func:`copy.copy` and :func:`copy.deepcopy` on Sockets, Contexts
* Sun Jan 25 2015 arun@gmx.de
- update to version 14.5.0:
  * use pickle.DEFAULT_PROTOCOL by default in send_pickle
  * with the release of pip-6, OS X wheels are only marked as
    10.6-intel, indicating that they should be installable on any
    newer or single-arch Python.
  * raise SSHException on failed check of host key
  * fix method name in utils.wi32.allow_interrupt
  * fork-related fixes in garbage collection thread
  * add missing import in zmq.__init__, causing failure to import in
    some circumstances
* Sat Nov 29 2014 arun@gmx.de
- Update to version 14.4.1
  * Bugfixes for 14.4
  - SyntaxError on Python 2.6 in zmq.ssh
  - Handle possible bug in garbage collection after fork
- Changes from vesion 14.4.0
  * New features:
  - Experimental support for libzmq-4.1.0 rc (new constants, plus zmq.has()).
  - Update bundled libzmq to 4.0.5
  - Update bundled libsodium to 1.0.0
  - Fixes for SSH dialogs when using zmq.ssh to create tunnels
  - More build/link/load fixes on OS X and Solaris
  - Get Frame metadata via dict access (libzmq 4)
  - Contexts and Sockets are context managers (term/close on __exit__)
  - Add zmq.utils.win32.allow_interrupt context manager for catching SIGINT on Windows
  * Bugs fixed:
  - Bundled libzmq should not trigger recompilation after install on PyPy
* Wed Oct  1 2014 toddrme2178@gmail.com
- Update to 14.3.1
  + Minor bugfixes to pyzmq 14.3:
  * Fixes to building bundled libzmq on OS X < 10.9
  * Fixes to import-failure warnings on Python 3.4
  * Fixes to tests
  * Pull upstream fixes to zmq.ssh for ssh multiplexing
- Changes from vesion 14.3.0
  + PyZMQ no longer calls :meth:`.Socket.close` or
    :meth:`.Context.term` during process cleanup.
    Changes to garbage collection in Python 3.4 make this
    impossible to do sensibly.
  + :meth:`ZMQStream.close` closes its socket immediately,
    rather than scheduling a timeout.
  + Raise the original ImportError when importing zmq fails.
    Should be more informative than `no module cffi...`.
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Fri Apr 25 2014 andrea@opensuse.org
- update to version 14.2.0
  * Raise new ZMQVersionError when a requested method is not
    supported by the linked libzmq. For backward compatibility, this
    subclasses NotImplementedError.
  * Bug fixes
* Fri Apr 12 2013 toddrme2178@gmail.com
- Add python3 requires and buildrequires.  It will not work without them
- Changes suggests to recommends since there is no way to install suggets currently
* Wed Mar 27 2013 speilicke@suse.com
- Update to version 13.0.0:
  + PyPy support
  + The Threadsafe ZMQStream experiment in 2.2.0.1 was deemed inappropriate and not useful,
    and has been removed.
  + The zmq.web experiment has been removed, to be developed as a standalone project
  + Fixes bnc#811890
- Add rpmlintrc
- Drop useless macros
- Run testsuite
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Fri May 18 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
* Fri Apr 27 2012 highwaystar.ru@gmail.com
- fixed building of python3 package on openSUSE 11.4 and older
* Tue Mar 27 2012 saschpe@suse.de
- Update to version 2.1.11:
  * remove support for LABEL prefixes. A major feature of libzmq-3.0, the LABEL
    prefix, has been removed from libzmq, prior to the first stable libzmq 3.x release.
  * The prefix argument to ~.Socket.send_multipart remains, but it continue to behave in
    exactly the same way as it always has on 2.1.x, simply prepending message parts.
  * ~.Socket.recv_multipart will always return a list, because prefixes are once
    again indistinguishable from regular message parts.
  * add .Socket.poll method, for simple polling of events on a single socket.
  * no longer require monkeypatching tornado IOLoop.  The :class:.ioloop.ZMQPoller class
    is a poller implementation that matches tornado's expectations, and pyzmq sockets can
    be used with any tornado application just by specifying the use of this poller. The
    pyzmq IOLoop implementation now only trivially differs from tornado's.
- Don't package documentation sources
* Tue Jan 31 2012 saschpe@suse.de
- Update to version 2.1.11:
  * remove support for LABEL prefixes.
  * add :meth:`.Socket.poll` method, for simple polling of events on a single socket.
  * no longer require monkeypatching tornado IOLoop.
- Moved Python-3 package into seperate spec file
* Mon Dec  5 2011 toddrme2178@gmail.com
- Cleaned up spec file formatting
- Added python3 subpackage
* Mon Sep 26 2011 cfarrell@suse.com
- license update: LGPL-3.0+
  LGPL is not a recognized license
* Fri Aug 19 2011 saschpe@suse.de
- Update to version 2.1.7:
  * Added proper GIL management for non-copying send
  * Implemented support for zmq_errno().
  * Added Socket.create_socket()
  * Fixed setup.py to work with libzmq.dll on Window
  * The flags argument to Socket.send/Socket.recv must be a C int
    to prevent Python-C API calls in the nogil section.
  * Added a protocol argument to pyobj_send that defaults to -1 (the
    highest pickle protocol).
  * Added a try/finally in Socket.recv.
* Sun Dec 12 2010 saschpe@gmx.de
- Re-generated with py2pack
  * now builds for all RPM-based distros
* Wed Dec  1 2010 saschpe@suse.de
- Initial version (2.0.10).
